# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.api_secret_api import ApiSecretApi


class TestApiSecretApi(unittest.TestCase):
    """ApiSecretApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApiSecretApi()

    def tearDown(self) -> None:
        pass

    def test_apisecret_create(self) -> None:
        """Test case for apisecret_create

        Creates an API secret
        """
        pass

    def test_apisecret_delete(self) -> None:
        """Test case for apisecret_delete

        Deletes an API secret
        """
        pass

    def test_apisecret_get(self) -> None:
        """Test case for apisecret_get

        Gets an API secret
        """
        pass

    def test_apisecret_list(self) -> None:
        """Test case for apisecret_list

        Lists all API secrets
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.collection_api import CollectionApi


class TestCollectionApi(unittest.TestCase):
    """CollectionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CollectionApi()

    def tearDown(self) -> None:
        pass

    def test_collection_create(self) -> None:
        """Test case for collection_create

        Creates a collection
        """
        pass

    def test_collection_delete(self) -> None:
        """Test case for collection_delete

        Deletes collection
        """
        pass

    def test_collection_get(self) -> None:
        """Test case for collection_get

        Gets a collection
        """
        pass

    def test_collection_list(self) -> None:
        """Test case for collection_list

        Lists all collections
        """
        pass

    def test_collection_update(self) -> None:
        """Test case for collection_update

        Updates a collection
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.extension import Extension

class TestExtension(unittest.TestCase):
    """Extension unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Extension:
        """Test Extension
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Extension`
        """
        model = Extension()
        if include_optional:
            return Extension(
                manifest = picteus_ws_client.models.manifest.Manifest(
                    id = 'extension-id', 
                    version = '1.0.0', 
                    name = 'My extension', 
                    description = 'Computes the embeddings of images.', 
                    runtimes = [
                        picteus_ws_client.models.manifest_runtime.ManifestRuntime(
                            environment = python, )
                        ], 
                    instructions = [
                        picteus_ws_client.models.manifest_instructions.ManifestInstructions(
                            events = [
                                'process.started'
                                ], 
                            capabilities = [
                                picteus_ws_client.models.manifest_capability.ManifestCapability(
                                    id = image.embeddings, )
                                ], 
                            throttling_policies = [
                                picteus_ws_client.models.manifest_throttling_policy.ManifestThrottlingPolicy(
                                    events = [
                                        'process.started'
                                        ], 
                                    duration_in_milliseconds = 1000, 
                                    maximum_count = 10, )
                                ], 
                            execution = null, 
                            commands = [
                                picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                                    id = 'convert', 
                                    on = null, 
                                    parameters = picteus_ws_client.models.parameters.parameters(), 
                                    specifications = [
                                        picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                                            locale = 'en', 
                                            label = 'Resize an image', 
                                            description = 'Resizes an image given a format asked to the user.', )
                                        ], )
                                ], )
                        ], 
                    settings = {type=object, properties={key={type=string, title=Key, description=A key.}}, required=[key]}, 
                    ui = null, ),
                status = 'enabled'
            )
        else:
            return Extension(
                manifest = picteus_ws_client.models.manifest.Manifest(
                    id = 'extension-id', 
                    version = '1.0.0', 
                    name = 'My extension', 
                    description = 'Computes the embeddings of images.', 
                    runtimes = [
                        picteus_ws_client.models.manifest_runtime.ManifestRuntime(
                            environment = python, )
                        ], 
                    instructions = [
                        picteus_ws_client.models.manifest_instructions.ManifestInstructions(
                            events = [
                                'process.started'
                                ], 
                            capabilities = [
                                picteus_ws_client.models.manifest_capability.ManifestCapability(
                                    id = image.embeddings, )
                                ], 
                            throttling_policies = [
                                picteus_ws_client.models.manifest_throttling_policy.ManifestThrottlingPolicy(
                                    events = [
                                        'process.started'
                                        ], 
                                    duration_in_milliseconds = 1000, 
                                    maximum_count = 10, )
                                ], 
                            execution = null, 
                            commands = [
                                picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                                    id = 'convert', 
                                    on = null, 
                                    parameters = picteus_ws_client.models.parameters.parameters(), 
                                    specifications = [
                                        picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                                            locale = 'en', 
                                            label = 'Resize an image', 
                                            description = 'Resizes an image given a format asked to the user.', )
                                        ], )
                                ], )
                        ], 
                    settings = {type=object, properties={key={type=string, title=Key, description=A key.}}, required=[key]}, 
                    ui = null, ),
                status = 'enabled',
        )
        """

    def testExtension(self):
        """Test Extension"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.user_interface_anchor import UserInterfaceAnchor

class TestUserInterfaceAnchor(unittest.TestCase):
    """UserInterfaceAnchor unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUserInterfaceAnchor(self):
        """Test UserInterfaceAnchor"""
        # inst = UserInterfaceAnchor()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from picteus_ws_client.models.manifest_extension_command_on import ManifestExtensionCommandOn
from picteus_ws_client.models.manifest_extension_command_specification import ManifestExtensionCommandSpecification
from typing import Optional, Set
from typing_extensions import Self

class ManifestExtensionCommand(BaseModel):
    """
    The definition of an extension's command
    """ # noqa: E501
    id: Annotated[str, Field(min_length=1, strict=True, max_length=32)] = Field(description="The identifier of the command")
    on: ManifestExtensionCommandOn = Field(description="The kind of entity and the conditions the command applies to")
    parameters: Optional[Dict[str, Any]] = Field(default=None, description="The definition of the parameters the command requires")
    specifications: Annotated[List[ManifestExtensionCommandSpecification], Field(min_length=1)] = Field(description="The specifications for the command")
    __properties: ClassVar[List[str]] = ["id", "on", "parameters", "specifications"]

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9A-Z-_.]{1,32}$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9A-Z-_.]{1,32}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ManifestExtensionCommand from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of on
        if self.on:
            _dict['on'] = self.on.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in specifications (list)
        _items = []
        if self.specifications:
            for _item_specifications in self.specifications:
                if _item_specifications:
                    _items.append(_item_specifications.to_dict())
            _dict['specifications'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ManifestExtensionCommand from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "on": ManifestExtensionCommandOn.from_dict(obj["on"]) if obj.get("on") is not None else None,
            "parameters": obj.get("parameters"),
            "specifications": [ManifestExtensionCommandSpecification.from_dict(_item) for _item in obj["specifications"]] if obj.get("specifications") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ImageFeatureFormat(str, Enum):
    """
    All the possible formats for an image feature.
    """

    """
    allowed enum values
    """
    STRING = 'string'
    INTEGER = 'integer'
    FLOAT = 'float'
    BOOLEAN = 'boolean'
    JSON = 'json'
    XML = 'xml'
    MARKDOWN = 'markdown'
    HTML = 'html'
    BINARY = 'binary'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ImageFeatureFormat from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.settings_api import SettingsApi


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SettingsApi()

    def tearDown(self) -> None:
        pass

    def test_settings_get(self) -> None:
        """Test case for settings_get

        Gets all the settings
        """
        pass

    def test_settings_set(self) -> None:
        """Test case for settings_set

        Sets all the settings
        """
        pass


if __name__ == '__main__':
    unittest.main()
